pub struct DisplayIdsFlags { /* private fields */ }Expand description
Bitfield in NV_GPU_DISPLAYIDS
Implementations
Sourceimpl DisplayIdsFlags
impl DisplayIdsFlags
Sourcepub const DYNAMIC: DisplayIdsFlags
pub const DYNAMIC: DisplayIdsFlags
This display is part of MST topology and it’s a dynamic
Sourcepub const MST_ROOT_NODE: DisplayIdsFlags
pub const MST_ROOT_NODE: DisplayIdsFlags
This displayID belongs to a multi stream enabled connector(root node). Note that when multi stream is enabled and a single multi stream capable monitor is connected to it, the monitor will share the display id with the RootNode.
Sourcepub const ACTIVE: DisplayIdsFlags
pub const ACTIVE: DisplayIdsFlags
This display is being actively driven
Sourcepub const CLUSTER: DisplayIdsFlags
pub const CLUSTER: DisplayIdsFlags
This display is the representative display
Sourcepub const OS_VISIBLE: DisplayIdsFlags
pub const OS_VISIBLE: DisplayIdsFlags
This display is reported to the OS
Sourcepub const WIRELESS: DisplayIdsFlags
pub const WIRELESS: DisplayIdsFlags
This display is wireless
Sourcepub const CONNECTED: DisplayIdsFlags
pub const CONNECTED: DisplayIdsFlags
This display is connected
Sourcepub const RESERVED_INTERNAL: DisplayIdsFlags
pub const RESERVED_INTERNAL: DisplayIdsFlags
Do not use
Sourcepub const PHYSICALLY_CONNECTED: DisplayIdsFlags
pub const PHYSICALLY_CONNECTED: DisplayIdsFlags
this display is a phycially connected display; Valid only when is Connected bit is set
Sourcepub const RESERVED: DisplayIdsFlags
pub const RESERVED: DisplayIdsFlags
must be zero
Sourcepub const fn empty() -> DisplayIdsFlags ⓘ
pub const fn empty() -> DisplayIdsFlags ⓘ
Returns an empty set of flags.
Sourcepub const fn all() -> DisplayIdsFlags ⓘ
pub const fn all() -> DisplayIdsFlags ⓘ
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: u32) -> Option<DisplayIdsFlags>
pub const fn from_bits(bits: u32) -> Option<DisplayIdsFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> DisplayIdsFlags ⓘ
pub const fn from_bits_truncate(bits: u32) -> DisplayIdsFlags ⓘ
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> DisplayIdsFlags ⓘ
pub const unsafe fn from_bits_unchecked(bits: u32) -> DisplayIdsFlags ⓘ
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: DisplayIdsFlags) -> bool
pub const fn intersects(&self, other: DisplayIdsFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: DisplayIdsFlags) -> bool
pub const fn contains(&self, other: DisplayIdsFlags) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: DisplayIdsFlags)
pub fn insert(&mut self, other: DisplayIdsFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: DisplayIdsFlags)
pub fn remove(&mut self, other: DisplayIdsFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: DisplayIdsFlags)
pub fn toggle(&mut self, other: DisplayIdsFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: DisplayIdsFlags, value: bool)
pub fn set(&mut self, other: DisplayIdsFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: DisplayIdsFlags) -> DisplayIdsFlags ⓘ
pub const fn intersection(self, other: DisplayIdsFlags) -> DisplayIdsFlags ⓘ
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: DisplayIdsFlags) -> DisplayIdsFlags ⓘ
pub const fn union(self, other: DisplayIdsFlags) -> DisplayIdsFlags ⓘ
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: DisplayIdsFlags) -> DisplayIdsFlags ⓘ
pub const fn difference(self, other: DisplayIdsFlags) -> DisplayIdsFlags ⓘ
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(
self,
other: DisplayIdsFlags,
) -> DisplayIdsFlags ⓘ
pub const fn symmetric_difference( self, other: DisplayIdsFlags, ) -> DisplayIdsFlags ⓘ
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> DisplayIdsFlags ⓘ
pub const fn complement(self) -> DisplayIdsFlags ⓘ
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.